// Author: Valeri Fine (fine@bnl.gov)
{


  //
  // This macro reads one event from the ROOT file produced by Atlasfast
  // to create and plot one histogram from the ExamplAnalysis  directory
  //
  // Note:   
  // ----
  // Top get the next event TFileIter::operator++() can be employed.
  //---------------------------------------------------------------------
  //
     gSystem->Load("libRootKernel");
     gSystem->Load("libPhysics");
     gSystem->Load("libEventHdrAthenaRootDataDef");
     gSystem->Load("libLArAthenaRootDataDef");
     gSystem->Load("libAthenaRootCnvSvc");

     // -- Create a ROOT file to hold histograms
     TFile histFile("LArCell_hist.root","RECREATE");
     // -- Let's book histograms:
     TH1F *hist_numCell =  new TH1F("NumCell", "NumCell",50,0,1000);
     TH1F *hist_cellE  =  new TH1F("CellE",   "CellE",50,0.,100.);
     TH1F *hist_cellEta  =  new TH1F("CellEta","CellEta",100,-2.5,2.5);
     TH1F *hist_cellPhi  =  new TH1F("CellPhi","CellPhi",100,0,6.283);

//--
//  Create a file iterator to loop over events stored within ROOT file
//--
     TFileIter nextEvent("LArCell.root");

     for(;(const char *)nextEvent != 0;nextEvent.SkipObjects()) 
      {
//--
//  Pick first event via TFileIter::operator*()
//--
       ATDataSet *event = (ATDataSet*)(*nextEvent);

//--
//  open ROOT browser to show this event
//--
       //     new TBrowser("Atlfast",event);    

       // Get EventInfo object 
       ATDataSet* tds  = event->FindByName("2101");
       ATDataSetIter next(tds); 
       EventInfoRoot* eventInfo = (EventInfoRoot*) next.Next(); 
       EventInfoRoot::iterator row_it    = eventInfo->begin();
       EventInfoRoot_t& row = *row_it; 
       int runNum = row.runNumber;  
       int eventNum = row.eventNumber; 

       cout <<" Run/Event numbr = "<<runNum<<" "<<eventNum<<endl; 

       LArCellContainerRoot *Cells =
	 (LArCellContainerRoot *)event->FindByName("LArEM");

       int n = 0; 
       if (Cells) {
	 LArCellContainerRoot::iterator Cell     = Cells->begin();
	 LArCellContainerRoot::iterator lastCell = Cells->end();
	 for (;Cell!=lastCell; Cell++){
	   ++n; 
	   // get the row
	   LArCellContainerRoot_t& tt = *Cell;
	   hist_cellE->Fill(tt.energy);
	   hist_cellEta->Fill(tt.eta);
	   hist_cellPhi->Fill(tt.phi);
	 } 
       }
       hist_numCell->Fill(n);     
      }
     
     TCanvas * canvas = new TCanvas("LArCell"); 
     canvas->Divide(2,2);
     
     
     canvas->cd(1); 
     canvas->SetLogy(); 
     hist_cellE->Draw();
     canvas->cd(2); 
     canvas->SetLogy(0); 
     hist_cellEta->Draw();
     canvas->cd(3); 
     hist_cellPhi->Draw();
     canvas->cd(4); 
     hist_numCell->Draw();
     
     histFile->Write(); 
     //  histFile->Close(); 
     
}












